pub enum DependencySourceError {
InvalidSource {
reason: &'static str,
},
VersionRequirement(VersionRequirementError),
GitCommit(GitCommitError),
InvalidUrl(String),
InvalidGitPath(GitModulePathError),
}Expand description
An error parsing a DependencySource.
Variants
InvalidSource
The dependency does not name a valid source.
The dependency must specify exactly one of path for a local-path
source, or git with exactly one of version, tag, branch, or
commit for a Git source. The reason describes which rule was
violated by the input.
VersionRequirement(VersionRequirementError)
A version requirement on a Git dependency was invalid.
GitCommit(GitCommitError)
A Git commit selector was invalid.
InvalidUrl(String)
The Git URL did not parse.
InvalidGitPath(GitModulePathError)
The path field on a Git dependency was invalid.