pub enum ProjectValidationError {
MissingFile {
kind: ProjectFileKind,
path: PathBuf,
},
NotRegularFile {
kind: ProjectFileKind,
path: PathBuf,
},
ExcludedFile {
kind: ProjectFileKind,
path: PathBuf,
},
Io {
kind: ProjectFileKind,
path: PathBuf,
source: Error,
},
Content(HashError),
}Expand description
An error validating a loaded module project.
Variants
MissingFile
A required manifest-referenced file does not exist.
Fields

kind: ProjectFileKindThe role of the missing file.
NotRegularFile
A required manifest reference does not resolve to a regular file.
Fields

kind: ProjectFileKindThe role of the invalid file.
ExcludedFile
A required manifest reference is omitted from module content hashing.
Fields

kind: ProjectFileKindThe role of the excluded file.
Io
Inspecting a required manifest-referenced file failed.
Fields

kind: ProjectFileKindThe role of the file.
Content(HashError)
Module content violated a tree or hashing invariant.