pub enum SignatureFileError {
InvalidJson(Error),
Key(KeyError),
Signature(SignatureError),
}Expand description
An error parsing or writing a module.sig file.
Variants
InvalidJson(Error)
The file is not valid JSON.
Key(KeyError)
The public_key field could not be parsed as an OpenSSH Ed25519
public key.
Signature(SignatureError)
The signature field could not be parsed as a base64-encoded
64-byte Ed25519 signature.