HashError

Enum HashError 

pub enum HashError {
    InvalidPath(RelativePathError),
    AbsoluteNotUnderRoot(String),
    AmbiguousPath {
        path: String,
        nfc: String,
    },
    Io {
        path: PathBuf,
        source: Error,
    },
    Walk(ModuleWalkError),
    Tree(TreeError),
}
An error during content hashing.

Variants



InvalidPath(RelativePathError)

A path supplied to Hasher::try_add failed relative-path validation.



AbsoluteNotUnderRoot(String)

An absolute path was supplied that does not live under the module root.



AmbiguousPath

A new path collides under Unicode Normalization Form C (NFC) with a path that was already recorded. The spec requires the module’s set of relative paths to be unique under NFC.

Fields

path: String

The newly-submitted path that collided.

nfc: String

The shared NFC form.



Io

I/O failure while reading a file.

Fields

path: PathBuf

The path of the file that failed to read.

source: Error

The underlying I/O error.



Walk(ModuleWalkError)

A tree walk error (symlink containment, metadata target, etc.).



Tree(TreeError)

A module file-tree validation error (reserved-filename placement, NFC duplicate paths).